@@ -49,6 +49,8 @@ class Revision(object):
         """Returns true if self.node == other.node"""
         return self.node == other.node
 
+
+
 class Repo(object):
     """A representation of a Mercurial repository"""
     def __init__(self, path, user=None):
@@ -56,9 +58,25 @@ class Repo(object):
         self.path = path
         self.cfg = False
         self.user = user
-        self._env = os.environ
-        self._env[str('LANG')] = str('en_US')
-		
+    
+    _env = os.environ
+    _env[str('LANG')] = str('en_US')
+
+    @classmethod
+    def command(cls, path, env, *args):
+        """Run a hg command in path and return the result. Throws on error."""
+        proc = Popen(["hg", "--cwd", path, "--encoding", "UTF-8"] + list(args),
+                 stdout=PIPE, stderr=PIPE, env=env)
+
+        out, err = [x.decode("utf-8") for x in proc.communicate()]
+
+        if proc.returncode:
+            cmd = (" ".join(["hg", "--cwd", path] + list(args)))
+            raise HgException("Error running %s:\n\tErr: %s\n\tOut: %s\n\tExit: %s"
+                              % (cmd, err, out, proc.returncode), exit_code=proc.returncode)
+
+        return out
+
     def __getitem__(self, rev=slice(0, 'tip')):
         """Get a Revision object for the revision identifed by rev
            rev can be a range (6c31a9f7be7ac58686f0610dd3c4ba375db2472c:tip)
@@ -70,17 +88,8 @@ class Repo(object):
         return self.revision(rev)
 
     def hg_command(self, *args):
-        """Run a hg command in path and return the result.
-        Throws on error."""    
-        proc = Popen(["hg", "--cwd", self.path, "--encoding", "UTF-8"] + list(args), stdout=PIPE, stderr=PIPE, env=self._env)
-
-        out, err = [x.decode("utf-8") for x in  proc.communicate()]
-
-        if proc.returncode:
-            cmd = (" ".join(["hg", "--cwd", self.path] + list(args)))
-            raise HgException("Error running %s:\n\tErr: %s\n\tOut: %s\n\tExit: %s" 
-                            % (cmd,err,out,proc.returncode), exit_code=proc.returncode)
-        return out
+        """Run a hg command. Throws on error."""
+        return Repo.command(self.path, self._env, *args)
 
     def hg_init(self):
         """Initialize a new repo"""
@@ -363,4 +372,18 @@ class Repo(object):
         if value.count(","):
             return value.split(",")
         else:
-            return value.split()
\ No newline at end of file
+            return value.split()
+
+    @classmethod
+    def hg_version(cls):
+        """Return the version number of Mercurial."""
+        out = Repo.command(".", os.environ, "version")
+        match = re.search('\s\(version (.*)\)$', out.split("\n")[0])
+        return match.group(1)
+
+    @classmethod
+    def hg_clone(cls, url, path, *args):
+        """Clone repository at given `url` to `path`,
+        then return repo object to `path`."""
+        Repo.command(".", os.environ, "clone", url, path, *args)
+        return Repo(path)
\ No newline at end of file
